.. toctree::
    :caption: Introduction
    :hidden:
    
    introduction

.. toctree::
    :caption: Modules
    :hidden:
    
    pychemcurv
    analysis
    visualization
    geometry

.. include:: introduction.rst



